<?php
/*
 * Plugin Name: Chaosmap Sticky Footer
 * Version: 1.0
 * Plugin URI: https://chaosmap.com/wordpress/plugins/sticky-footer-message/
 * Description: This plugin will create a sticky footer for your website.
 * Author: Chaosmap
 * Author URI: https://chaosmap.com/
 * License: GPL version 2 or later - http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 * Requires at least: 4.0
 * Tested up to: 4.6.1
 *
 *
 * @package WordPress
 * @author Chaosmap
 * @since 1.0.0
 */

class ChaosmapStickyFooter{


    function __construct()
    {
        add_action('customize_register',array($this, 'sticky_footer_customize_register'));
        add_action('wp_footer', array($this, 'sticky_footer'));
    }


    function sticky_footer_customize_register( $wp_customize ) {

        $wp_customize->add_section( 'chaosmap_sticky_footer', array(
            'priority' => 1000,
            'capability' => 'edit_theme_options',
            'theme_supports' => '',
            'title' => __( 'Chaosmap Sticky Footer'),
            'description' => 'Chaosmap Sticky Footer customisation options.',
        ) );


        /**
         * Bg color
         */
        $wp_customize->add_setting( 'chaosmap_sticky_footer_bg_color', array(
            'default'        => 'cccccc',
            'type'           => 'option',
            'transport'         => 'postMessage',
            'sanitize_callback'    => 'sanitize_hex_color_no_hash',
            'sanitize_js_callback' => 'maybe_hash_hex_color',
        ) );

        $wp_customize->add_control( new WP_Customize_Color_Control(
            $wp_customize,
            'chaosmap_sticky_footer_bg_color_control',
            array(
                'label'   => __( 'Background Color'),
                'section' => 'chaosmap_sticky_footer',
                'settings'   => 'chaosmap_sticky_footer_bg_color',
            ) ) );



        /**
         * Border settings
         */
        $wp_customize->add_setting( 'chaosmap_sticky_footer_border_color', array(
            'default'        => '64C0BB',
            'transport'         => 'postMessage',
            'type'           => 'option',
            'sanitize_callback'    => 'sanitize_hex_color_no_hash',
            'sanitize_js_callback' => 'maybe_hash_hex_color',
        ) );

        $wp_customize->add_control( new WP_Customize_Color_Control(
            $wp_customize,
            'chaosmap_sticky_footer_border_color_control',
            array(
                'label'   => __( 'Border Color'),
                'section' => 'chaosmap_sticky_footer',
                'settings'   => 'chaosmap_sticky_footer_border_color',
            ) )
        );

        /**
         * Text settings
         */

        $wp_customize->add_setting( 'chaosmap_sticky_footer_text', array(
            'default' => 'Sticky footer text.',
            'type' => 'option',
            'transport' => 'postMessage',
            'capability' => 'edit_theme_options',
            //'sanitize_callback' => 'sanitize_text_field',
            //'sanitize_js_callback' => '',
        ) );

        $wp_customize->add_control( 'chaosmap_sticky_footer_text', array(
            'type' => 'textarea',
            'priority' => 10,
            'section' => 'chaosmap_sticky_footer',
            'label' => __( 'Footer Text' ),
            'description' => __( 'Sticky footer text.' ),
        ) );

        $wp_customize->add_setting( 'chaosmap_sticky_footer_text_color', array(
            'default'        => 'ffffff',
            'type'           => 'option',
            'transport'      => 'postMessage',
            'sanitize_callback'    => 'sanitize_hex_color_no_hash',
            'sanitize_js_callback' => 'maybe_hash_hex_color',
        ) );


        $wp_customize->add_control( new WP_Customize_Color_Control(
                $wp_customize,
                'chaosmap_sticky_footer_text_color_control',
                array(
                    'label'   => __( 'Text Color'),
                    'section' => 'chaosmap_sticky_footer',
                    'settings'   => 'chaosmap_sticky_footer_text_color',
                ) )
        );


        $wp_customize->add_setting( 'chaosmap_sticky_footer_text_link_color', array(
            'default'        => '27a0d5',
            'type'           => 'option',
            'transport'      => 'postMessage',
            'sanitize_callback'    => 'sanitize_hex_color_no_hash',
            'sanitize_js_callback' => 'maybe_hash_hex_color',
        ) );


        $wp_customize->add_control( new WP_Customize_Color_Control(
                $wp_customize,
                'chaosmap_sticky_footer_text_link_color_control',
                array(
                    'label'   => __( 'Text Link Color'),
                    'section' => 'chaosmap_sticky_footer',
                    'settings'   => 'chaosmap_sticky_footer_text_link_color',
                ) )
        );

        $wp_customize->add_setting( 'chaosmap_sticky_footer_text_size', array(
            'default' => 16,
            'type' => 'option',
            'capability' => 'edit_theme_options',
            'transport' => 'postMessage',
        ) );

        $wp_customize->add_control( 'chaosmap_sticky_footer_text_size', array(
            'type' => 'range',
            'priority' => 10,
            'section' => 'chaosmap_sticky_footer',
            'label' => __( 'Text Size'),
            'description' => 'Sticky footer text size.',
            'input_attrs' => array(
                'min' => 10,
                'max' => 100,
                'step' => 1,
                'class' => 'example-class',
                'style' => 'color: #0a0',
            ),
        ) );


        if ( $wp_customize->is_preview() && ! is_admin() ){
            add_action( 'wp_footer', array($this, 'sticky_footer_customize_preview'), 21);
        }

    }


    function sticky_footer_customize_preview(){
            ?>
            <script type="text/javascript">
                ( function( $ ){

                    wp.customize('chaosmap_sticky_footer_bg_color',function( value ) {
                        value.bind(function(to) {
                            $('#chaosmap-sticky-footer').css('background', to ? to : '' );
                        });
                    });

                    wp.customize('chaosmap_sticky_footer_border_color',function( value ) {
                        value.bind(function(to) {
                            $('#chaosmap-sticky-footer').css('border-top-color', to ? to : '' );
                        });
                    });

                    wp.customize('chaosmap_sticky_footer_text',function( value ) {
                        value.bind(function(to) {
                            $('#chaosmap-sticky-footer .chaosmap-sticky-content-container p').html( to ? to : '' );
                        });
                    });

                    wp.customize('chaosmap_sticky_footer_text_color',function( value ) {
                        value.bind(function(to) {
                            $('#chaosmap-sticky-footer .chaosmap-sticky-content-container p').css('color', to ? to : '' );
                        });
                    });

                    wp.customize('chaosmap_sticky_footer_text_size',function( value ) {
                        value.bind(function(to) {
                            $('#chaosmap-sticky-footer .chaosmap-sticky-content-container p').css('font-size', to ? to+'px' : '16px' );
                        });
                    });

                    wp.customize('chaosmap_sticky_footer_text_link_color',function( value ) {
                        value.bind(function(to) {
                            $('#chaosmap-sticky-footer .chaosmap-sticky-content-container p a').css('color', to ? to : '' );
                        });
                    });

                } )( jQuery )
            </script>
            <?php
    }

    public static function sticky_footer()
    {
        ?>
        <style>
            #chaosmap-sticky-footer{
                background: #<?php echo get_option('chaosmap_sticky_footer_bg_color'); ?>;
                position: fixed;
                bottom: 0;
                width: 100%;
                min-height: 50px;
                color: #<?php echo get_option('chaosmap_sticky_footer_text_color'); ?>;
                text-align: center;
                border-top: 5px solid #<?php echo get_option('chaosmap_sticky_footer_border_color'); ?>;
                z-index: 9999;
            }
            .chaosmap-sticky-content-container{
                text-align: center;
                width: 1320px;
                max-width: 90%;
                margin: auto;
                padding: 20px;
            }
            .chaosmap-sticky-content-container p{
                font-size: <?php echo get_option('chaosmap_sticky_footer_text_size', '16'); ?>px;
                line-height: 1.6;
                margin: 0;
                padding: 0;
            }

            .chaosmap-sticky-content-container p a{
                color: #<?php echo get_option('chaosmap_sticky_footer_text_link_color','#27a0d5'); ?>;
            }
            footer{
                padding-bottom: 55px;
            }

            @media (max-width: 720px) {
                .chaosmap-sticky-content-container{
                    /*line-height: 26px;*/
                    font-size: 14px;
                    padding: 10px 0;
                }
                footer{
                    padding-bottom: 70px;
                }
            }
        </style>

        <div id="chaosmap-sticky-footer" class="dark-grey" style="">
            <div class="chaosmap-sticky-content-container">
               <p> <?php echo get_option('chaosmap_sticky_footer_text', 'Chaosmap sticky footer text.'); ?> </p>
            </div>
        </div>
        <?php
    }
}
new ChaosmapStickyFooter();


